globalThis.chrome = globalThis.browser;

import '../../../adblocker/dist/es6/src/data-view.js';
export { adsAndTrackingLists, adsLists, fetchLists, fetchResources, fetchWithRetry, fullLists } from '../../../adblocker/dist/es6/src/fetch.js';
export { default as CosmeticFilter } from '../../../adblocker/dist/es6/src/filters/cosmetic.js';
export { default as NetworkFilter } from '../../../adblocker/dist/es6/src/filters/network.js';
export { default as Request, getHostnameHashesFromLabelsBackward } from '../../../adblocker/dist/es6/src/request.js';
import '../../../../@remusao/small/dist/es6/index.js';
import { isUTF8 } from '../../../adblocker/dist/es6/src/encoding.js';
import StreamingHtmlFilter from '../../../adblocker/dist/es6/src/html-filtering.js';

/*!
 * Copyright (c) 2017-present Cliqz GmbH. All rights reserved.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/.
 */
function isFirefox() {
    try {
        return navigator.userAgent.indexOf('Firefox') !== -1;
    }
    catch (e) {
        return false;
    }
}
/**
 * There are different ways to inject scriptlets ("push" vs "pull").
 * This function should decide based on the environment what to use:
 *
 * 1) "Pushing" means the adblocker will listen on "onCommitted" events
 *    and then execute scripts by running the tabs.executeScript API.
 * 2) "Pulling" means the adblocker will inject a content script, which
 *    runs before the page loads (and on the DOM changes), fetches
 *    scriplets from the background and runs them.
 *
 * Note:
 * - the "push" model requires permission to the webNavigation API.
 *   If that is not available, the implementation will fall back to the
 *   "pull" model, which does not have this requirement.
 */
function usePushScriptsInjection() {
    // There is no fundamental reason why it should not work on Firefox,
    // but given that there are no known issues with Firefox, let's keep
    // the old, proven technique until there is evidence that changes
    // are needed.
    //
    // Take YouTube as an example: on Chrome (or forks like Edge), the adblocker
    // will sometimes fail to block ads if you reload the page multiple times;
    // on Firefox, the same steps do not seem to trigger any ads.
    return !isFirefox();
}
usePushScriptsInjection();
/**
 * Helper used when injecting custom CSP headers to update `responseHeaders`.
 */
function updateResponseHeadersWithCSP(details, policies) {
    if (policies === undefined) {
        return {};
    }
    let responseHeaders = details.responseHeaders || [];
    const CSP_HEADER_NAME = 'content-security-policy';
    // Collect existing CSP headers from response
    responseHeaders.forEach(({ name, value }) => {
        if (name.toLowerCase() === CSP_HEADER_NAME) {
            policies += `; ${value}`;
        }
    });
    // Remove all CSP headers from response
    responseHeaders = responseHeaders.filter(({ name }) => name.toLowerCase() !== CSP_HEADER_NAME);
    // Add updated CSP header
    responseHeaders.push({ name: CSP_HEADER_NAME, value: policies });
    return { responseHeaders };
}
/**
 * Enable stream HTML filter on request `id` using `rules`.
 */
function filterRequestHTML(filterResponseData, { id }, rules) {
    // Create filter to observe loading of resource
    const filter = filterResponseData(id);
    const decoder = new TextDecoder();
    const encoder = new TextEncoder();
    const htmlFilter = new StreamingHtmlFilter(rules);
    const teardown = (event) => {
        // Before disconnecting our streaming filter, we need to be extra careful
        // and make sure that no data remains in either our streaming `TextDecoder`
        // instance or the HTML filterer.
        //
        // In case any data remains, we write it to filter.
        try {
            const remaining = htmlFilter.write(decoder.decode()) + htmlFilter.flush();
            if (remaining.length !== 0) {
                filter.write(encoder.encode(remaining));
            }
        }
        catch (ex) {
            // If we reach this point, there is probably no way we can recover...
            console.error('Failed to flush HTML filterer', ex);
        }
        // If latest event had some data attached (i.e. 'ondata' event), we make
        // sure to flush it through the filterer before disconnecting.
        if (event.data !== undefined) {
            filter.write(event.data);
        }
        // Disconnect streaming filter.
        filter.disconnect();
    };
    filter.ondata = (event) => {
        // On any chunk of data we implementa very fast UTF-8 validity check to make
        // sure that we will be able to decode it. Note that in theory it should be
        // possible that a chunk ends on the boundary of a multi-byte UTF-8 code and
        // this check would fail?
        if (isUTF8(new Uint8Array(event.data)) === false) {
            return teardown(event);
        }
        try {
            filter.write(encoder.encode(htmlFilter.write(decoder.decode(event.data, { stream: true }))));
        }
        catch (ex) {
            // If we fail to decode a chunk, we need to be extra conservative and stop
            // listening to streaming response. Teardown takes care of flushing any
            // data remaining in the pipeline and disconnecting the listener.
            return teardown(event);
        }
    };
    filter.onstop = () => {
        teardown({});
    };
}

export { StreamingHtmlFilter, filterRequestHTML, isUTF8, updateResponseHeadersWithCSP };
