globalThis.chrome = globalThis.browser;

import logger from '../../logger.js';

/**
 * WhoTracks.Me
 * https://whotracks.me/
 *
 * Copyright 2017-present Ghostery GmbH. All rights reserved.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0
 */


class Subject {
  constructor() {
    this.listeners = new Set();
  }

  subscribe(callback) {
    this.listeners.add(callback);
    return {
      unsubscribe: () => {
        this.listeners.delete(callback);
      },
    };
  }

  pub(message) {
    this.listeners.forEach((listener) => {
      try {
        listener(message);
      } catch (e) {
        logger.error('Subject failed to notify listener', e);
      }
    });
  }
}

export { Subject as default };
